@@ -4,20 +4,16 @@
 #include <vector>
 #include <cmath>
 
-#define TBB_PREVIEW_GLOBAL_CONTROL 1
-
 #define TIMING
 
 #ifdef TIMING
 
 #include <map>
 #include <iomanip>
-#include <random>
 #include "Timing.h"
 
 #endif // TIMING
 
-#include "threefry.h"
 #include "MemoryManagement.h"
 #include "Simd.h"
 #include "ZigZag.h"
